# -*- coding: utf-8 -*-
from django.contrib import admin
from django_admin import ExportExcelModelAdmin, ReadonlyModelAdmin
from TimeConvert import TimeConvert as tc

from tamron.models import (TamronActivityInfo, TamronClassInfo, TamronNavEnInfo, TamronPhotographicWorkInfo,
                           TamronProductInfo, TamronRegisterInfo, TamronServiceInfo, TamronSliderInfo, TamronStoreInfo,
                           TamronUserInfo)


class TamronSliderInfoAdmin(admin.ModelAdmin):
    list_display = ('fid', 'pic', 'url', 'px')
    list_filter = ('fid', )


# class TamronNavInfoAdmin(admin.ModelAdmin):
#     list_display = ('lanmu', 'pic', 'url', 'px')
#     list_filter = ('lanmu', )


class TamronNavEnInfoAdmin(admin.ModelAdmin):
    list_filter = ('id', 'pic')


class TamronRegisterInfoAdmin(admin.ModelAdmin):
    list_display = ('fid', 'title', 'px')
    list_filter = ('fid', )


class TamronProductInfoInline(admin.TabularInline):
    model = TamronProductInfo


class TamronUserInfoAdmin(admin.ModelAdmin):
    list_display = ('user', 'sex', 'zhiwei', 'tel', 'email', 'xinghao', 'gzleixing', 'gxtedian', 'created_at')
    list_filter = ('sex', 'zhiwei', 'pinpai', 'xinghao')
    fieldsets = (
        (None, {
            'fields': ('user', 'sex', 'zhiwei', 'tel', 'email', 'pinpai', 'xinghao', 'gzleixing', 'gxtedian', 'time', 'shifou', 'chanpin', 'gmtime')
        }),
        ('腾龙', {
            'fields': ('cpxinghao', 'cpkakou', 'xuliehao', 'product_info')
        }),
    )
    readonly_fields = ('product_info', )
    search_fields = ('user', 'tel', 'email', 'id')
    # inlines = (TamronProductInfoInline, )


# class TamronProductInfoAdmin(admin.ModelAdmin):
#    list_display = ('msg_id', 'user_name', 'xuliehao', 'xinghao', 'kakou', 'gtime', 'ctime')
#    list_filter = ('xinghao', 'kakou')
#    search_fields = ('msg_id', 'kakou')


class TamronActivityInfoAdmin(admin.ModelAdmin):
    list_display = ('pk', 'pic', 'title', 'description', 'seo_key', 'seo_des', 'isindex', 'px', 'ctime')
    readonly_fields = ('ctime', )

    def save_model(self, request, obj, form, change):
        obj.ctime = tc.local_string(format='%Y-%m-%d')
        obj.save()


class TamronClassInfoAdmin(admin.ModelAdmin):
    list_display = ('pic', 'title', 'description', 'seo_key', 'seo_des', 'isindex', 'px', 'ctime')
    readonly_fields = ('ctime', )

    def save_model(self, request, obj, form, change):
        obj.ctime = tc.local_string(format='%Y-%m-%d')
        obj.save()


class TamronServiceInfoAdmin(admin.ModelAdmin):
    list_display = ('title', 'content', 'seo_key', 'seo_des', 'px')


class TamronStoreInfoAdmin(admin.ModelAdmin):
    list_display = ('fid', 'sid', 'title', 'add', 'tel', 'px')
    list_filter = ('fid', )


class TamronPhotographicWorkInfoAdmin(admin.ModelAdmin):
    list_display = ('msg_id', 'title', 'pinpai', 'xinghao', 'guangquan', 'kuaimen', 'jiaoju', 'ganguang', 'zt', 'px', 'ctime')
    list_filter = ('msg_id', 'pinpai')


admin.site.register(TamronSliderInfo, TamronSliderInfoAdmin)
# admin.site.register(TamronNavInfo, TamronNavInfoAdmin)
admin.site.register(TamronNavEnInfo, TamronNavEnInfoAdmin)
admin.site.register(TamronRegisterInfo, TamronRegisterInfoAdmin)
admin.site.register(TamronUserInfo, TamronUserInfoAdmin)
# admin.site.register(TamronProductInfo, TamronProductInfoAdmin)
admin.site.register(TamronActivityInfo, TamronActivityInfoAdmin)
admin.site.register(TamronClassInfo, TamronClassInfoAdmin)
admin.site.register(TamronServiceInfo, TamronServiceInfoAdmin)
admin.site.register(TamronStoreInfo, TamronStoreInfoAdmin)
admin.site.register(TamronPhotographicWorkInfo, TamronPhotographicWorkInfoAdmin)
