# -*- coding: utf-8 -*-

import time

from django.db import models
from django.utils.translation import ugettext_lazy as _
from django_models_ext import upload_path


class TamronSliderInfo(models.Model):
    HOME = 1
    PGIST = 2

    SLIEDER_TYPE_TUPLE = (
        (HOME, u'首页轮播图'),
        (PGIST, u'产品注册页轮播图'),
    )

    fid = models.IntegerField(_(u'fid'), choices=SLIEDER_TYPE_TUPLE, default=HOME, help_text=u'轮播图类型')
    pic = models.FileField(_(u'pic'), upload_to=upload_path, blank=True, null=True, help_text=u'轮播图图片')
    url = models.CharField(_(u'url'), max_length=255, blank=True, null=True, help_text=u'轮播图链接')
    px = models.IntegerField(_(u'px'), default=1, help_text=u'排序（降序）')

    class Meta:
        verbose_name = _(u'轮播图信息')
        verbose_name_plural = _(u'轮播图信息')
        db_table = 'shidu_banner'

    def __unicode__(self):
        return unicode(self.pk)


# class TamronNavInfo(models.Model):
#     lanmu = models.CharField(_(u'lanmu'), default=0, help_text=u'标题')
#     pic = models.FileField(_(u'pic'), upload_to=upload_path, blank=True, null=True, help_text=u'作品图片')
#     url = models.CharField(_(u'url'), max_length=255, blank=True, null=True, help_text=u'作品链接')
#     px = models.IntegerField(_(u'px'), default=1, help_text=u'排序（降序）')

#     class Meta:
#         verbose_name = _(u'会员作品信息')
#         verbose_name_plural = _(u'会员作品信息')
#         db_table = 'shidu_nav'

#     def __unicode__(self):
#         return unicode(self.pk)


class TamronNavEnInfo(models.Model):
    pic = models.FileField(_(u'pic'), upload_to=upload_path, blank=True, null=True, help_text=u'作品图片')

    class Meta:
        verbose_name = _(u'页面嵌入图片')
        verbose_name_plural = _(u'页面嵌入图片')
        db_table = 'shidu_naven'

    def __unicode__(self):
        return unicode(self.pk)


class TamronRegisterInfo(models.Model):
    BRAND = 1
    MODEL = 2
    SERIES = 3
    BAYONET = 4
    METIER = 5

    REGISTER_TYPE_TUPLE = (
        (BRAND, u'相机品牌'),
        (MODEL, u'相机型号'),
        (SERIES, u'产品型号'),
        (BAYONET, u'相机卡口'),
        (METIER, u'职业'),
    )

    fid = models.IntegerField(_(u'fid'), choices=REGISTER_TYPE_TUPLE, default=BRAND, help_text=u'注册字段类型')
    title = models.CharField(_(u'title'), max_length=255, blank=True, null=True, help_text=u'注册字段值')
    px = models.IntegerField(_(u'px'), default=1, help_text=u'排序（降序）')

    class Meta:
        verbose_name = _(u'注册字段信息')
        verbose_name_plural = _(u'注册字段信息')
        db_table = 'shidu_zhuces'

    def __unicode__(self):
        return unicode(self.pk)


class TamronProductInfo(models.Model):
    msg_id = models.IntegerField(_(u'msg_id'), help_text=u'会员唯一标识')

    xuliehao = models.CharField(_(u'xuliehao'), max_length=32, blank=True, null=True, help_text=u'相机序列号')
    xinghao = models.CharField(_(u'xinghao'), max_length=32, blank=True, null=True, help_text=u'会员相机品牌')
    kakou = models.CharField(_(u'kakou'), max_length=32, blank=True, null=True, help_text=u'会员相机品牌')
    gtime = models.CharField(_(u'gtime'), max_length=10, blank=True, null=True, help_text=u'相机购买日期')

    ctime = models.IntegerField(_(u'ctime'), default=0, help_text=u'创建时间')

    # def user_name(self):
    #    if self.msg_id == 0:
    #        return ""
    #    user = TamronUserInfo.objects.filter(id=self.msg_id)[0]
    #    return user.user

    class Meta:
        verbose_name = _(u'产品注册信息')
        verbose_name_plural = _(u'产品注册信息')
        db_table = 'shidu_msg_chanpin'

    def __unicode__(self):
        return unicode(self.pk)


class TamronUserInfo(models.Model):
    title = models.CharField(_(u'title'), max_length=255, blank=True, null=True, help_text=u'???')
    name = models.CharField(_(u'name'), max_length=255, blank=True, null=True, help_text=u'???')
    content = models.CharField(_(u'content'), max_length=300, blank=True, null=True, help_text=u'???')
    gsname = models.CharField(_(u'gsname'), max_length=255, blank=True, null=True, help_text=u'???')
    lxname = models.CharField(_(u'lxname'), max_length=20, blank=True, null=True, help_text=u'???')
    dizhi = models.CharField(_(u'dizhi'), max_length=100, blank=True, null=True, help_text=u'???')

    user = models.CharField(_(u'user'), max_length=100, blank=True, null=True, help_text=u'会员帐户')
    sex = models.CharField(_(u'sex'), max_length=1, blank=True, null=True, help_text=u'会员性别')
    zhiwei = models.CharField(_(u'zhiwei'), max_length=32, blank=True, null=True, help_text=u'会员职业')
    tel = models.CharField(_(u'tel'), max_length=255, blank=True, null=True, help_text=u'会员手机号')
    email = models.CharField(_(u'email'), max_length=100, blank=True, null=True, help_text=u'会员邮箱')
    password = models.CharField(_(u'password'), max_length=100, blank=True, null=True, help_text=u'会员密码')

    province_id = models.IntegerField(_(u'province_id'), default=1, help_text=u'会员省份唯一标识')
    city_id = models.IntegerField(_(u'city_id'), default=1, help_text=u'会员城市唯一标识')

    pinpai = models.CharField(_(u'pinpai'), max_length=32, blank=True, null=True, help_text=u'会员相机品牌')
    xinghao = models.CharField(_(u'xinghao'), max_length=32, blank=True, null=True, help_text=u'会员相机品牌')
    gzleixing = models.CharField(_(u'gzleixing'), max_length=255, blank=True, null=True, help_text=u'近期关注镜头产品类型')
    gxtedian = models.CharField(_(u'gxtedian'), max_length=255, blank=True, null=True, help_text=u'购买镜头时最关心的产品特点')
    time = models.CharField(_(u'time'), max_length=10, blank=True, null=True, help_text=u'接触摄影时间')
    shifou = models.CharField(_(u'shifou'), max_length=8, blank=True, null=True, help_text=u'对腾龙镜头的了解程度')
    chanpin = models.CharField(_(u'chanpin'), max_length=8, blank=True, null=True, help_text=u'是否拥有腾龙产品')

    gmtime = models.CharField(_(u'gmtime'), max_length=10, blank=True, null=True, help_text=u'相机购买日期')
    cpxinghao = models.CharField(_(u'cpxinghao'), max_length=32, blank=True, null=True, help_text=u'会员相机品牌')
    cpkakou = models.CharField(_(u'cpkakou'), max_length=32, blank=True, null=True, help_text=u'会员相机品牌')
    xuliehao = models.CharField(_(u'xuliehao'), max_length=32, blank=True, null=True, help_text=u'相机序列号')

    pic = models.CharField(_(u'pic'), max_length=255, blank=True, null=True, help_text=u'会员头像')

    ctime = models.IntegerField(_(u'ctime'), default=0, help_text=u'创建时间')

    def product_info(self):
        product_infos = TamronProductInfo.objects.filter(msg_id=self.id)
        res = ''
        for product_info in product_infos:
            res += product_info.xinghao + '\n'
        return res

    def created_at(self):
        return time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(self.ctime))

    class Meta:
        verbose_name = _(u'会员注册信息')
        verbose_name_plural = _(u'会员注册信息')
        db_table = 'shidu_msg'

    def __unicode__(self):
        return unicode(self.pk)


class TamronActivityInfo(models.Model):
    pic = models.FileField(_(u'pic'), upload_to=upload_path, blank=True, null=True, help_text=u'活动图片')
    title = models.CharField(_(u'title'), max_length=255, blank=True, null=True, help_text=u'活动标题')
    description = models.TextField(_(u'description'), blank=True, null=True, help_text=u'活动描述')
    seo_key = models.CharField(_(u'seo_key'), max_length=255, blank=True, null=True, help_text=u'SEO 关键字')
    seo_des = models.TextField(_(u'seo_des'), blank=True, null=True, help_text=u'SEO 描述')
    isindex = models.IntegerField(_(u'isindex'), default=1, help_text=u'???')

    ctime = models.CharField(_(u'ctime'), max_length=10, blank=True, null=True, help_text=u'创建时间')

    px = models.IntegerField(_(u'px'), default=1, help_text=u'排序（降序）')

    class Meta:
        verbose_name = _(u'会员活动信息')
        verbose_name_plural = _(u'会员活动信息')
        db_table = 'shidu_activity'

    def __unicode__(self):
        return unicode(self.pk)


class TamronClassInfo(models.Model):
    pic = models.FileField(_(u'pic'), upload_to=upload_path, blank=True, null=True, help_text=u'活动图片')
    title = models.CharField(_(u'title'), max_length=255, blank=True, null=True, help_text=u'活动标题')
    description = models.TextField(_(u'description'), blank=True, null=True, help_text=u'活动描述')
    seo_key = models.CharField(_(u'seo_key'), max_length=255, blank=True, null=True, help_text=u'SEO 关键字')
    seo_des = models.TextField(_(u'seo_des'), blank=True, null=True, help_text=u'SEO 描述')
    isindex = models.IntegerField(_(u'isindex'), default=1, help_text=u'???')

    ctime = models.CharField(_(u'ctime'), max_length=10, blank=True, null=True, help_text=u'创建时间')

    px = models.IntegerField(_(u'px'), default=1, help_text=u'排序（降序）')

    class Meta:
        verbose_name = _(u'摄影课堂信息')
        verbose_name_plural = _(u'摄影课堂信息')
        db_table = 'shidu_ketang'

    def __unicode__(self):
        return unicode(self.pk)


class TamronServiceInfo(models.Model):
    title = models.CharField(_(u'title'), max_length=255, blank=True, null=True, help_text=u'服务标题')
    content = models.TextField(_(u'content'), blank=True, null=True, help_text=u'服务描述')
    seo_key = models.CharField(_(u'seo_key'), max_length=255, blank=True, null=True, help_text=u'SEO 关键字')
    seo_des = models.TextField(_(u'seo_des'), blank=True, null=True, help_text=u'SEO 描述')

    px = models.IntegerField(_(u'px'), default=1, help_text=u'排序（降序）')

    class Meta:
        verbose_name = _(u'延保服务')
        verbose_name_plural = _(u'延保服务')
        db_table = 'shidu_service'

    def __unicode__(self):
        return unicode(self.pk)


class TamronStoreInfo(models.Model):
    sid = models.IntegerField(_(u'sid'), default=1, help_text=u'省份唯一标识')
    fid = models.IntegerField(_(u'fid'), default=1, help_text=u'城市唯一标识')
    title = models.CharField(_(u'title'), max_length=255, blank=True, null=True, help_text=u'地区名称')
    add = models.CharField(_(u'add'), max_length=255, blank=True, null=True, help_text=u'???')
    tel = models.CharField(_(u'tel'), max_length=32, blank=True, null=True, help_text=u'联系电话')
    px = models.IntegerField(_(u'px'), default=1, help_text=u'排序（降序）')

    class Meta:
        verbose_name = _(u'实体店信息')
        verbose_name_plural = _(u'实体店信息')
        db_table = 'shidu_store'

    def __unicode__(self):
        return unicode(self.pk)


class TamronPhotographicWorkInfo(models.Model):
    msg_id = models.IntegerField(_(u'msg_id'), default=0, help_text=u'会员唯一标识')

    title = models.CharField(_(u'title'), max_length=255, blank=True, null=True, help_text=u'服务标题')
    content = models.TextField(_(u'content'), blank=True, null=True, help_text=u'服务描述')

    pic = models.CharField(_(u'pic'), max_length=255, blank=True, null=True, help_text=u'摄影作品链接')
    picen = models.CharField(_(u'picen'), max_length=255, blank=True, null=True, help_text=u'???')

    pinpai = models.CharField(_(u'pinpai'), max_length=255, blank=True, null=True, help_text=u'相机品牌')
    xinghao = models.CharField(_(u'xinghao'), max_length=255, blank=True, null=True, help_text=u'相机型号')
    jtpinpai = models.CharField(_(u'jtpinpai'), max_length=255, blank=True, null=True, help_text=u'???')
    jtxinghao = models.CharField(_(u'jtxinghao'), max_length=255, blank=True, null=True, help_text=u'???')
    guangquan = models.CharField(_(u'guangquan'), max_length=255, blank=True, null=True, help_text=u'相机光圈')
    kuaimen = models.CharField(_(u'kuaimen'), max_length=255, blank=True, null=True, help_text=u'相机快门')
    jiaoju = models.CharField(_(u'kuaimen'), max_length=255, blank=True, null=True, help_text=u'相机焦距')
    ganguang = models.CharField(_(u'kuaimen'), max_length=255, blank=True, null=True, help_text=u'相机感光')

    zt = models.IntegerField(_(u'zt'), default=2, help_text=u'???')
    px = models.IntegerField(_(u'px'), default=1, help_text=u'排序（降序）')

    ctime = models.IntegerField(_(u'ctime'), default=0, help_text=u'创建时间')

    gtime = models.IntegerField

    class Meta:
        verbose_name = _(u'摄影作品信息')
        verbose_name_plural = _(u'摄影作品信息')
        db_table = 'shidu_msg_zuopin'

    def __unicode__(self):
        return unicode(self.pk)
